==> api_server_controller-0.1.7a6-py3-none-any.whl: asc/core/tools/marketplace/mercadopago/api.py <==
from os import environ

from dotenv import load_dotenv, find_dotenv
from asc.core.ABC.APIRequestor import APIRequestor
from asc.core.tools.marketplace.mercadopago.data import PayerCustomer
from asc.core.tools.marketplace.mercadopago.data import Payment
from asc.core.tools.marketplace.mercadopago.data import Customer
from asc.core.tools.marketplace.mercadopago.data import Card
from asc.exceptions import mercadopago as exceptions_mercadopago

load_dotenv(find_dotenv())


class MercadoPago(APIRequestor):

    base_payload = {}
    base_api_url = environ.get('mercadopago__url_baseapi')
    base_headers = {
        'Accept': 'application/json',
        'Content-Type': 'application/json',
        'User-Agent': 'ASC-Tools-marketplace',
        'Authorization': ['Bearer', environ.get('mercadopago__access_token')]
    }

    _data_payer: PayerCustomer = None

    def __init__(self):
        super().__init__()

    def __response(self, response, parseAs: str = 'json'):
        if parseAs == 'json':
            resp = response.json()

            print('RESPONSE=',resp)

            if 'error' in resp:
                error_cause = resp['cause'][0]

                if error_cause['code'] == '101':
                    raise exceptions_mercadopago \
                        .CustomerAlreadyExistsException()

                if error_cause['code'] == '120':
                    raise exceptions_mercadopago \
                        .CardDoesNotExistsException()

                if error_cause['code'] == 'E205':
                    raise exceptions_mercadopago \
                        .CardInvalidExpirationYearException()

                raise exceptions_mercadopago.PaymentException(
                    f"{resp['message']} - {error_cause['description']} {error_cause['code']}"
                )

            return resp

        return response.text

    def GET_payment_methods(self):
        """
        Consulte todas as formas de pagamento disponíveis e obtenha
        uma lista com os detalhes de cada uma delas e suas propriedades.
        :return:
        """
        return self.__response(
            self.GET('v1/payment_methods')
        )

    def GET_identification_types(self):
        """
        Veja todos os tipos de documentos disponíveis por país e obtenha
        uma lista com a identificação e detalhes de cada um deles.
        :return:
        """
        return self.__response(
            self.GET('v1/identification_types')
        )

    def POST_payment(self, request_data:Payment):
        """ Envie o pagamento ao Mercado Pago.
        """
        print("PAYLOAD=",request_data)
        request_resp = self.__response(
            self.POST('v1/payments', request_data.asdict())
        )

        return request_resp

    def POST_payment_pix(self, transaction_amount:int, payer:PayerCustomer) -> dict:
        """
        Envia pagamento pix.
        :param amount: valor da cobrança.
        :param payer: dados do pagador.
        :return:
        """
        request_data = Payment(
            payment_method_id='pix',
            transaction_amount=transaction_amount,
            payer=payer,
            callback_url=environ.get('mercadopago__url_callback')
        )

        return self.POST_payment(request_data.asdict())

    def POST_customer(self, **data) -> dict:
        """
        Registra cliente.
        :return:
        """
        return self.__response(
            self.POST(
                'v1/customers',
                Customer(**data).asdict()
            )
        )

    def GET_customer_search(self, email:str) -> dict:
        """
        Encontre todas as informações do cliente
        através de filtros específicos.
        :param email: email do cliente a buscar.
        :return:
        """
        return self.__response(
            self.GET(
                'v1/customers/search',
                {'email':email}
            )
        )

    def GET_customer(self, id:str) -> dict:
        """
        Veja todas as informações de um cliente
        a partir da sua identificação.
        :param id: id do cliente a buscar.
        :return:
        """
        return self.__response(
            self.GET(
                f'v1/customers/{id}'
            )
        )

    def POST_card(self, card:Card) -> dict:
        """
        Obtém token para um cartão.
        :return:
        """
        card = card.asdict()
        print('CARD',card)
        return self.__response(
            self.POST(
                f'v1/card_tokens',
                card
            )
        )

    def POST_customer_card(self, id_customer:str, token:str) -> dict:
        """
        Atrela cartão a um cliente.
        :return:
        """
        return self.__response(
            self.POST(
                f'v1/customers/{id_customer}/cards',
                {
                    'token':token,
                }
            )
        )

==> api_server_controller-0.2.2a5-py3-none-any.whl: asc/core/tools/marketplace/mercadopago/api.py <==
from asc.core import env
from asc.core.ABC.APIRequestor import APIRequestor
from asc.core.tools.marketplace.mercadopago.data import PayerCustomer
from asc.core.tools.marketplace.mercadopago.data import Payment
from asc.core.tools.marketplace.mercadopago.data import Customer
from asc.core.tools.marketplace.mercadopago.data import Card
from asc.exceptions import mercadopago as exceptions_mercadopago


class MercadoPago(APIRequestor):

    base_payload = {}
    base_api_url = env.get('mercadopago__url_baseapi')
    base_headers = {
        'Accept': 'application/json',
        'Content-Type': 'application/json',
        'User-Agent': 'ASC-Tools-marketplace',
        'Authorization': ['Bearer', env.get('mercadopago__access_token')]
    }

    _data_payer: PayerCustomer = None

    def __init__(self):
        super().__init__()

    def __response(self, response, parseAs: str = 'json'):
        if parseAs == 'json':
            resp = response.json()

            print('RESPONSE=',resp)

            if 'error' in resp:
                error_cause = resp['cause'][0]

                if error_cause['code'] == '101':
                    raise exceptions_mercadopago \
                        .CustomerAlreadyExistsException()

                if error_cause['code'] == '120':
                    raise exceptions_mercadopago \
                        .CardDoesNotExistsException()

                if error_cause['code'] == 'E205':
                    raise exceptions_mercadopago \
                        .CardInvalidExpirationYearException()

                raise exceptions_mercadopago.PaymentException(
                    f"{resp['message']} - {error_cause['description']} {error_cause['code']}"
                )

            return resp

        return response.text

    def GET_payment(self, id_payment:int):
        """
        Consulte todas as informações de um pagamento
        através do ID de pagamento.
        :return:
        """
        return self.__response(
            self.GET(f'v1/payments/{id_payment}')
        )

    def GET_payment_methods(self):
        """
        Consulte todas as formas de pagamento disponíveis e obtenha
        uma lista com os detalhes de cada uma delas e suas propriedades.
        :return:
        """
        return self.__response(
            self.GET('v1/payment_methods')
        )

    def GET_identification_types(self):
        """
        Veja todos os tipos de documentos disponíveis por país e obtenha
        uma lista com a identificação e detalhes de cada um deles.
        :return:
        """
        return self.__response(
            self.GET('v1/identification_types')
        )

    def POST_payment(self, request_data:Payment):
        """ Envie o pagamento ao Mercado Pago.
        """
        print("PAYLOAD=",request_data)
        request_resp = self.__response(
            self.POST('v1/payments', request_data.asdict())
        )

        return request_resp

    def POST_payment_pix(self, transaction_amount:int, payer:PayerCustomer) -> dict:
        """
        Envia pagamento pix.
        :param amount: valor da cobrança.
        :param payer: dados do pagador.
        :return:
        """
        request_data = Payment(
            payment_method_id='pix',
            transaction_amount=transaction_amount,
            payer=payer,
            callback_url=env.get('mercadopago__url_callback')
        )

        return self.POST_payment(request_data.asdict())

    def POST_customer(self, **data) -> dict:
        """
        Registra cliente.
        :return:
        """
        return self.__response(
            self.POST(
                'v1/customers',
                Customer(**data).asdict()
            )
        )

    def GET_customer_search(self, email:str) -> dict:
        """
        Encontre todas as informações do cliente
        através de filtros específicos.
        :param email: email do cliente a buscar.
        :return:
        """
        return self.__response(
            self.GET(
                'v1/customers/search',
                {'email':email}
            )
        )

    def GET_customer(self, id:str) -> dict:
        """
        Veja todas as informações de um cliente
        a partir da sua identificação.
        :param id: id do cliente a buscar.
        :return:
        """
        return self.__response(
            self.GET(
                f'v1/customers/{id}'
            )
        )

    def POST_card(self, card:Card) -> dict:
        """
        Obtém token para um cartão.
        :return:
        """
        card = card.asdict()
        print('CARD',card)
        return self.__response(
            self.POST(
                f'v1/card_tokens',
                card
            )
        )

    def POST_customer_card(self, id_customer:str, token:str) -> dict:
        """
        Atrela cartão a um cliente.
        :return:
        """
        return self.__response(
            self.POST(
                f'v1/customers/{id_customer}/cards',
                {
                    'token':token
                }
            )
        )
